/*
 * This file is part of DesertGS, which is a GameScript for OpenTTD
 * Copyright (C) 2012  Leif Linse
 *
 * DesertGS is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License
 *
 * DesertGS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DesertGS; If not, see <http://www.gnu.org/licenses/> or
 * write to the Free Software Foundation, Inc., 51 Franklin Street, 
 * Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */


class MainClass extends GSController 
{
	_load_data = null;

	constructor()
	{
	}
}

function MainClass::Start()
{
	this.Init();

	// Wait for the game to start
	this.Sleep(1);

	// Welcome human player
	local HUMAN_COMPANY = 0;

	while (true) {
		local loop_start_tick = GSController.GetTick();

		this.HandleEvents();
		this.DoTest();

		// Loop with a frequency of five days
		local ticks_used = GSController.GetTick() - loop_start_tick;
		this.Sleep(max(1, 5 * 74 - ticks_used));
	}
}

function MainClass::Init()
{
	if (this._load_data != null)
	{
		// Copy loaded data from this._load_data to this.*
		// or do whatever with the loaded data

	}
	else
	{
		// Create desert/snow signs for all towns
		local towns = GSTownList();
		
		foreach(t, _ in towns) {
			local tile = GSTown.GetLocation(t);
			GSSign.BuildSign(tile, "desert:" + GSTile.IsDesertTile(tile) + " | snow:" + GSTile.IsSnowTile(tile));
		}
	}
}

function MainClass::HandleEvents()
{
	if(GSEventController.IsEventWaiting())
	{
		local ev = GSEventController.GetNextEvent();

		if(ev == null)
			return;

		// check event type
		// handle event
	}
}

function MainClass::Save()
{
	GSLog.Info("Saving data to savegame");
	return { 
		some_data = null,
		some_other_data = null
	};
}

function MainClass::Load(version, tbl)
{
	GSLog.Info("Loading data from savegame made with version " + version + " of the game script");

	// Store a copy of the table from the save game
	// but do not process the loaded data yet. Wait with that to Init
	// so that OpenTTD doesn't kick us for taking too long to load.
	this._load_data = {}
   	foreach(key, val in tbl)
	{
		this._load_data.rawset(key, val);
	}	
}

function MainClass::DoTest()
{
}
